(Boolean) Should the token be refreshed?
If no, a token will be read from a locally cached file '.bw_token' if this file is available.
If no token is available, or the refresh argument is TRUE, a new token will be requested and cached from the API.
cache
(Boolean) Can the token be locally cached?
If TRUE, the token will be cached in the current working directory in '.bw_token'.
If FALSE, the token will be not be cached locally.
Value
Invisibly returns the string containing the token returned by Brandwatch.
Your environment variable 'BW_TOKEN' will be set to the value of your authentication token.