Learn R Programming

brandwatchR (version 0.3.0)

bwr_cat_get: Get a data frame of available categories for a given project

Description

See the Brandwatch documentation for more information at https://developers.brandwatch.com/docs/retrieving-categories.

Usage

bwr_cat_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))

Arguments

project_id

The project id you'd like to return all available categories for. Obtain a data frame of projects using bwr_get_projects()

token

The auth token for this user, which should be generated into an environment variable using bwr_auth()

Value

Returns a dataframe of categories matching the project.

Examples

Run this code
# NOT RUN {
my_categories <- bwr_cat_get(project_id = 12334534)
# }

Run the code above in your browser using DataLab