(Optional) the target for your query. If not specified, results will include
all available projects for the authenticated user and all available data for each project.
If 'summary', results will be a more simplified list of projects and excludes richer data such as query links.
token
The Brandwatch token, which will be automatically available via environment
arguments provided you run bwr_auth() prior to any other functions.