powered by
Delete a specified Brandwatch query group
bwr_querygrp_delete(project_id = NULL, group_id = NULL, token = Sys.getenv("BW_TOKEN"))
The project ID in which your target query group can be found.
The query group ID which you'd like to delete. Find out the list of query groups in a given project using bwr_querygrp_get().
The API authentication token, obtained using bwr_auth()
Returns a list of the JSON response from the server.
# NOT RUN { kill <- bwr_querygrp_delete(project_id = 234234234, group_id = 23423423) # }
Run the code above in your browser using DataLab