Learn R Programming

brandwatchR (version 0.3.0)

bwr_querygrp_get: Get a data frame of Brandwatch query groups in the specified project

Description

Get a data frame of Brandwatch query groups in the specified project

Usage

bwr_querygrp_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))

Arguments

project_id

The project ID whose query groups you'd like to return

token

The authentication token, obtained using bwr_auth()

Value

Returns a data frame of the query groups for the given project, if any exist.

Examples

Run this code
# NOT RUN {
groups <- bwr_querygrp_get(project_id = 21343242)
# }

Run the code above in your browser using DataLab