Learn R Programming

brandwatchR (version 0.3.0)

bwr_rule_get: Get a data frame of available rules for a given project

Description

See the Brandwatch documentation for more information at https://developers.brandwatch.com/docs/retrieving-rules.

Usage

bwr_rule_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))

Arguments

project_id

The project id you'd like to return all available rules for. Obtain a data frame of projects using bwr_get_projects()

token

The auth token for this user, which should be generated into an environment variable using bwr_auth()

Value

Returns a dataframe of rules matching the project. Due to the structure of the API response, some of the dataframe columns are list-columns (i.e. nested dataframes).

Examples

Run this code
# NOT RUN {
my_rules <- bwr_rules_get(project_id = 12334534)
# }

Run the code above in your browser using DataLab