Learn R Programming

brandwatchR (version 0.3.0)

bwr_wf_get: Get a list of workflows for the specified query and project

Description

Refer to https://developers.brandwatch.com/docs/retrieving-workflow for more information.

Usage

bwr_wf_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))

Arguments

project_id

The project id in which the specified workflow is contained. Obtain a list of project IDs using bwr_get_projects().

token

The authentication token, acquired using bwr_auth()

Value

Returns a list containing all results

Examples

Run this code
# NOT RUN {
my_project <- bwr_get_projects()$id[1]
my_workflow <- bwr_wf_get(project_id = my_project)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab