powered by
See the Brandwatch documentation for more information at https://developers.brandwatch.com/docs/retrieving-categories.
bwr_cat_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))
The project id you'd like to return all available categories for. Obtain a data frame of projects using bwr_get_projects()
The auth token for this user, which should be generated into an environment variable using bwr_auth()
Returns a dataframe of categories matching the project.
# NOT RUN { my_categories <- bwr_cat_get(project_id = 12334534) # }
Run the code above in your browser using DataLab