bwr_metrics_get: Get a data frame of possible metric values for the Brandwatch API
Description
When examining parameters which can be used to filter a metric call, some parameters have a limited set of acceptable values. You can find out the current acceptable values using this function.
Usage
bwr_metrics_get(token = Sys.getenv("BW_TOKEN"))
Arguments
token
The auth token for this user, which should be generated into an environment variable using bwr_auth()
Value
Returns a dataframe of available filters
Details
See the Brandwatch documentation for more information at https://developers.brandwatch.com/docs/available-filters