powered by
Get a data frame of Brandwatch query groups in the specified project
bwr_querygrp_get(project_id = NULL, token = Sys.getenv("BW_TOKEN"))
The project ID whose query groups you'd like to return
The authentication token, obtained using bwr_auth()
Returns a data frame of the query groups for the given project, if any exist.
# NOT RUN { groups <- bwr_querygrp_get(project_id = 21343242) # }
Run the code above in your browser using DataLab