The project id you'd like to return all available rules for. Obtain a data frame of projects using bwr_get_projects()
token
The auth token for this user, which should be generated into an environment variable using bwr_auth()
Value
Returns a dataframe of rules matching the project. Due to the structure of the API response, some of the dataframe columns are list-columns (i.e. nested dataframes).